// 初始化declarativeNetRequest规则
chrome.declarativeNetRequest.updateDynamicRules({
  addRules: [
    {
      id: 1,
      priority: 1,
      action: {
        type: 'allow',
      },
      condition: {
        urlFilter: 'https://www.baidu.com/sugrec',
        resourceTypes: ['xmlhttprequest'],
      },
    },
  ],
  removeRuleIds: [1],
});

// 处理来自内容脚本的消息
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
  if (request.action === 'fetchBaiduSuggestion') {
    const url = `https://www.baidu.com/sugrec?prod=pc&wd=${encodeURIComponent(request.query)}`;

    fetch(url)
      .then(response => {
        if (!response.ok) {
          throw new Error(`HTTP error! status: ${response.status}`);
        }
        return response.json();
      })
      .then(data => {
        sendResponse({ success: true, data });
      })
      .catch(error => {
        console.error('Fetch error:', error);
        sendResponse({ success: false, error: error.message });
      });

    return true; // 保持消息通道打开以等待异步响应
  }
});

// 消息类型常量
const UPDATE_TAB_TITLE = 'UPDATE_TAB_TITLE';
const SHOW_NOTIFICATION = 'SHOW_NOTIFICATION';
const DEBUG = 'DEBUG';
const NOTIFICATION_PREFIX = 'notification_';

// 消息监听
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
  if (request.type === UPDATE_TAB_TITLE) {
    console.log('UPDATE_TAB_TITLE', request.title);
    chrome.tabs.update(sender.tab.id, { title: request.title });
  }
  if (request.type === DEBUG) {
    console.log(request.message);
  }
  if (request.type === SHOW_NOTIFICATION) {
    const notificationId = NOTIFICATION_PREFIX + Date.now();
    chrome.notifications.create(notificationId, request.message);
  }
});

// 通知点击时，激活微信视频号页面
chrome.notifications.onClicked.addListener(notificationId => {
  chrome.tabs.query({ url: 'https://channels.weixin.qq.com/*' }, tabs => {
    if (tabs.length > 0) {
      chrome.tabs.update(tabs[0].id, { active: true });
      chrome.windows.update(tabs[0].windowId, { focused: true });
    }
  });
  chrome.notifications.clear(notificationId);
});
